aiscalator package — AIscalator 0.1.0 documentation

### Navigation

- ☰
- AIscalator-0.1.0 »
- aiscalator »

Fork me on GitHub

# aiscalator package

## Subpackages

- aiscalator.airflow package
  - Submodules
  - aiscalator.airflow.cli module
  - Module contents
- aiscalator.core package
  - Submodules
  - aiscalator.core.config module
  - aiscalator.core.log_regex_analyzer module
  - aiscalator.core.utils module
  - Module contents
- aiscalator.jupyter package
  - Submodules
  - aiscalator.jupyter.cli module
  - Module contents

## Submodules

## aiscalator.cli module

Command Line Interface of the AIscalator tool.

Using the python click package (https://click.palletsprojects.com/en/7.x/), this module defines all the entry points to the application.

## Module contents

Aiscalator Module: CLI to AIscalate

### Navigation

- index
- modules |
- next |
- previous |